@@ -73,36 +73,36 @@
 extern "C" {
 #endif
 
-#define CUFFT_VER_MAJOR 11
-#define CUFFT_VER_MINOR 4
-#define CUFFT_VER_PATCH 1
-#define CUFFT_VER_BUILD 4
+#define CUFFT_VER_MAJOR 12
+#define CUFFT_VER_MINOR 0
+#define CUFFT_VER_PATCH 0
+#define CUFFT_VER_BUILD 15
 
-#define CUFFT_VERSION 11401
+#define CUFFT_VERSION 12000
 
 // CUFFT API function return values
 typedef enum cufftResult_t {
-  CUFFT_SUCCESS        = 0x0,
-  CUFFT_INVALID_PLAN   = 0x1,
-  CUFFT_ALLOC_FAILED   = 0x2,
-  CUFFT_INVALID_TYPE   = 0x3,
-  CUFFT_INVALID_VALUE  = 0x4,
-  CUFFT_INTERNAL_ERROR = 0x5,
-  CUFFT_EXEC_FAILED    = 0x6,
-  CUFFT_SETUP_FAILED   = 0x7,
-  CUFFT_INVALID_SIZE   = 0x8,
-  CUFFT_UNALIGNED_DATA = 0x9,
-  CUFFT_INCOMPLETE_PARAMETER_LIST = 0xA,
-  CUFFT_INVALID_DEVICE = 0xB,
-  CUFFT_PARSE_ERROR = 0xC,
-  CUFFT_NO_WORKSPACE = 0xD,
-  CUFFT_NOT_IMPLEMENTED = 0xE,
-  CUFFT_LICENSE_ERROR = 0x0F,
-  CUFFT_NOT_SUPPORTED = 0x10
-
+  CUFFT_SUCCESS            = 0x0,
+  CUFFT_INVALID_PLAN       = 0x1,
+  CUFFT_ALLOC_FAILED       = 0x2,
+  CUFFT_INVALID_TYPE       = 0x3,
+  CUFFT_INVALID_VALUE      = 0x4,
+  CUFFT_INTERNAL_ERROR     = 0x5,
+  CUFFT_EXEC_FAILED        = 0x6,
+  CUFFT_SETUP_FAILED       = 0x7,
+  CUFFT_INVALID_SIZE       = 0x8,
+  CUFFT_UNALIGNED_DATA     = 0x9,
+  CUFFT_INVALID_DEVICE     = 0xB,
+  CUFFT_NO_WORKSPACE       = 0xD,
+  CUFFT_NOT_IMPLEMENTED    = 0xE,
+  CUFFT_NOT_SUPPORTED      = 0x10,
+  CUFFT_MISSING_DEPENDENCY = 0x11,
+  CUFFT_NVRTC_FAILURE      = 0x12,
+  CUFFT_NVJITLINK_FAILURE  = 0x13,
+  CUFFT_NVSHMEM_FAILURE    = 0x14
 } cufftResult;
 
-#define MAX_CUFFT_ERROR 0x11
+#define MAX_CUFFT_ERROR 0x15
 
 
 // CUFFT defines and supports the following data types
@@ -148,6 +148,8 @@ typedef enum cufftCompatibility_t {
 // cufftHandle is a handle type used to store and access CUFFT plans.
 typedef int cufftHandle;
 
+// an uninitialized cufftHandle that is safe to call cufftDestroy on
+#define CUFFT_PLAN_NULL -1
 
 cufftResult CUFFTAPI cufftPlan1d(cufftHandle *plan,
                                  int nx,
@@ -311,19 +313,19 @@ cufftResult CUFFTAPI cufftGetProperty(libraryPropertyType type,
                                       int *value);
 
 //
-// Set/Get PlanProperty APIs configures per-plan behavior 
+// Set/Get PlanProperty APIs configures per-plan behavior
 //
 typedef enum cufftProperty_t {
     NVFFT_PLAN_PROPERTY_INT64_PATIENT_JIT = 0x1,
     NVFFT_PLAN_PROPERTY_INT64_MAX_NUM_HOST_THREADS = 0x2,
 } cufftProperty;
 
-cufftResult CUFFTAPI cufftSetPlanPropertyInt64(cufftHandle plan, 
-                                               cufftProperty property, 
+cufftResult CUFFTAPI cufftSetPlanPropertyInt64(cufftHandle plan,
+                                               cufftProperty property,
                                                const long long int inputValueInt);
 
-cufftResult CUFFTAPI cufftGetPlanPropertyInt64(cufftHandle plan, 
-                                               cufftProperty property, 
+cufftResult CUFFTAPI cufftGetPlanPropertyInt64(cufftHandle plan,
+                                               cufftProperty property,
                                                long long int* returnPtrValue);
 
 cufftResult CUFFTAPI cufftResetPlanProperty(cufftHandle plan, cufftProperty property);
