@@ -68,10 +68,10 @@ typedef __int64 int64_t;
 
 typedef int cusolver_int_t;
 
-  #define CUSOLVER_VER_MAJOR 11
-  #define CUSOLVER_VER_MINOR 7
-  #define CUSOLVER_VER_PATCH 5
-  #define CUSOLVER_VER_BUILD 82
+  #define CUSOLVER_VER_MAJOR 12
+  #define CUSOLVER_VER_MINOR 0
+  #define CUSOLVER_VER_PATCH 3
+  #define CUSOLVER_VER_BUILD 29
   #define CUSOLVER_VERSION                                                     \
     (CUSOLVER_VER_MAJOR * 1000 + CUSOLVER_VER_MINOR * 100 + CUSOLVER_VER_PATCH)
 
@@ -93,11 +93,15 @@ typedef int cusolver_int_t;
 
       #define CUSOLVER_DEPRECATED(new_func)                                    \
         [[deprecated("please use " #new_func " instead")]]
+      #define CUSOLVER_DEPRECATED_                                  \
+        [[deprecated]]
 
     #elif defined(_MSC_VER)
 
       #define CUSOLVER_DEPRECATED(new_func)                                    \
         __declspec(deprecated("please use " #new_func " instead"))
+      #define CUSOLVER_DEPRECATED_                                  \
+        __declspec(deprecated)
 
     #elif defined(__INTEL_COMPILER) || defined(__clang__) ||                   \
       (defined(__GNUC__) &&                                                    \
@@ -105,14 +109,18 @@ typedef int cusolver_int_t;
 
       #define CUSOLVER_DEPRECATED(new_func)                                    \
         __attribute__((deprecated("please use " #new_func " instead")))
+      #define CUSOLVER_DEPRECATED_                                  \
+        __attribute__((deprecated))
 
     #elif defined(__GNUC__) || defined(__xlc__)
 
       #define CUSOLVER_DEPRECATED(new_func) __attribute__((deprecated))
+      #define CUSOLVER_DEPRECATED_ __attribute__((deprecated))
 
     #else
 
       #define CUSOLVER_DEPRECATED(new_func)
+      #define CUSOLVER_DEPRECATED_
 
     #endif // defined(__cplusplus) && __cplusplus >= 201402L
   //------------------------------------------------------------------------------
@@ -137,6 +145,7 @@ typedef int cusolver_int_t;
   #else // defined(DISABLE_CUSOLVER_DEPRECATED)
 
     #define CUSOLVER_DEPRECATED(new_func)
+    #define CUSOLVER_DEPRECATED_
     #define CUSOLVER_DEPRECATED_ENUM(new_enum)
 
   #endif // !defined(DISABLE_CUSOLVER_DEPRECATED)
@@ -249,6 +258,16 @@ extern "C" {
     CUBLAS_DIRECT_BACKWARD = 1
   } cusolverDirectMode_t;
 
+  typedef enum {
+    CUSOLVER_DETERMINISTIC_RESULTS = 1,
+    CUSOLVER_ALLOW_NON_DETERMINISTIC_RESULTS = 2
+  } cusolverDeterministicMode_t;
+
+  typedef enum {
+      CUSOLVER_DEFAULT_MATH = 1,
+      CUSOLVER_FP32_EMULATED_BF16X9_MATH = 2,
+  } cusolverMathMode_t;
+  
   cusolverStatus_t CUSOLVERAPI
     cusolverGetProperty(libraryPropertyType type, int *value);
 
