@@ -67,10 +67,10 @@
 #define NVJPEG_MAX_COMPONENT 4
 
 // nvjpeg version information
-#define NVJPEG_VER_MAJOR 12
-#define NVJPEG_VER_MINOR 3
-#define NVJPEG_VER_PATCH 5
-#define NVJPEG_VER_BUILD 92
+#define NVJPEG_VER_MAJOR 13
+#define NVJPEG_VER_MINOR 0
+#define NVJPEG_VER_PATCH 0
+#define NVJPEG_VER_BUILD 40
 
 /* nvJPEG status enums, returned by nvJPEG API */
 typedef enum
@@ -123,34 +123,40 @@ typedef enum
 typedef enum
 {
     // return decompressed image as it is - write planar output
-    NVJPEG_OUTPUT_UNCHANGED   = 0,
+    NVJPEG_OUTPUT_UNCHANGED      = 0,
     // return planar luma and chroma, assuming YCbCr colorspace
-    NVJPEG_OUTPUT_YUV         = 1, 
+    NVJPEG_OUTPUT_YUV            = 1, 
     // return luma component only, if YCbCr colorspace, 
     // or try to convert to grayscale,
     // writes to 1-st channel of nvjpegImage_t
-    NVJPEG_OUTPUT_Y           = 2,
+    NVJPEG_OUTPUT_Y              = 2,
     // convert to planar RGB 
-    NVJPEG_OUTPUT_RGB         = 3,
+    NVJPEG_OUTPUT_RGB            = 3,
     // convert to planar BGR
-    NVJPEG_OUTPUT_BGR         = 4, 
+    NVJPEG_OUTPUT_BGR            = 4, 
     // convert to interleaved RGB and write to 1-st channel of nvjpegImage_t
-    NVJPEG_OUTPUT_RGBI        = 5, 
+    NVJPEG_OUTPUT_RGBI           = 5, 
     // convert to interleaved BGR and write to 1-st channel of nvjpegImage_t
-    NVJPEG_OUTPUT_BGRI        = 6,
+    NVJPEG_OUTPUT_BGRI           = 6,
     // 16 bit unsigned output in interleaved format
     NVJPEG_OUTPUT_UNCHANGEDI_U16 = 7,
+    // 2 channels: Y and UV (at half horizontal + vertical resolution - 420)
+    NVJPEG_OUTPUT_NV12           = 8,
+    // One channel: YUYV YUYV ... (U and V are at half horizontal resolution - 422)
+    NVJPEG_OUTPUT_YUY2           = 9,
     // maximum allowed value
-    NVJPEG_OUTPUT_FORMAT_MAX  = 7
+    NVJPEG_OUTPUT_FORMAT_MAX     = 9
 } nvjpegOutputFormat_t;
 
 // Parameter of this type specifies what type of input user provides for encoding
 typedef enum
 {
+    NVJPEG_INPUT_YUV         = 1, // Input is YUV (or YCbCr)
     NVJPEG_INPUT_RGB         = 3, // Input is RGB - will be converted to YCbCr before encoding
     NVJPEG_INPUT_BGR         = 4, // Input is RGB - will be converted to YCbCr before encoding
     NVJPEG_INPUT_RGBI        = 5, // Input is interleaved RGB - will be converted to YCbCr before encoding
-    NVJPEG_INPUT_BGRI        = 6  // Input is interleaved RGB - will be converted to YCbCr before encoding
+    NVJPEG_INPUT_BGRI        = 6, // Input is interleaved RGB - will be converted to YCbCr before encoding
+    NVJPEG_INPUT_NV12        = 8, // Input is 2 channels: Y and UV (at half horizontal + vertical resolution - 420)
 } nvjpegInputFormat_t;
 
 // Implementation
@@ -172,6 +178,13 @@ typedef enum
     NVJPEG_BACKEND_LOSSLESS_JPEG = 6,
 } nvjpegBackend_t;
 
+typedef enum
+{
+    NVJPEG_ENC_BACKEND_DEFAULT = 0,
+    NVJPEG_ENC_BACKEND_GPU = 1,
+    NVJPEG_ENC_BACKEND_HARDWARE = 2,
+} nvjpegEncBackend_t;
+
 // Currently parseable JPEG encodings (SOF markers)
 typedef enum
 {
@@ -334,6 +347,8 @@ nvjpegStatus_t NVJPEGAPI nvjpegGetHardwareDecoderInfo(nvjpegHandle_t handle,
         unsigned int* num_engines,
         unsigned int* num_cores_per_engine);
 
+nvjpegStatus_t NVJPEGAPI nvjpegGetHardwareEncoderInfo(nvjpegHandle_t handle,
+        unsigned int* num_engines);
 
 // Initalization of decoding state
 // IN         handle        : Library handle
@@ -472,6 +487,12 @@ nvjpegStatus_t NVJPEGAPI nvjpegEncoderStateCreate(
         nvjpegEncoderState_t *encoder_state,
         cudaStream_t stream);
 
+nvjpegStatus_t NVJPEGAPI nvjpegEncoderStateCreateWithBackend(
+    nvjpegHandle_t handle,
+    nvjpegEncoderState_t *encoder_state,
+    nvjpegEncBackend_t  backend,
+    cudaStream_t stream);
+
 nvjpegStatus_t NVJPEGAPI nvjpegEncoderStateDestroy(nvjpegEncoderState_t encoder_state);
 
 struct nvjpegEncoderParams;
@@ -504,6 +525,11 @@ nvjpegStatus_t NVJPEGAPI nvjpegEncoderParamsSetSamplingFactors(
         const nvjpegChromaSubsampling_t chroma_subsampling,
         cudaStream_t stream);
 
+nvjpegStatus_t NVJPEGAPI nvjpegEncoderParamsSetRestartInterval(
+        nvjpegEncoderParams_t encoder_params,
+        unsigned int restart_interval,
+        cudaStream_t stream);
+
 nvjpegStatus_t NVJPEGAPI nvjpegEncodeGetBufferSize(
         nvjpegHandle_t handle,
         const nvjpegEncoderParams_t encoder_params,
@@ -531,6 +557,17 @@ nvjpegStatus_t NVJPEGAPI nvjpegEncodeImage(
         int image_height,
         cudaStream_t stream);
 
+nvjpegStatus_t NVJPEGAPI nvjpegEncode(
+        nvjpegHandle_t handle,
+        nvjpegEncoderState_t encoder_state,
+        const nvjpegEncoderParams_t encoder_params,
+        const nvjpegImage_t* source,
+        nvjpegChromaSubsampling_t input_subsampling,
+        nvjpegInputFormat_t input_format,
+        int image_width,
+        int image_height,
+        cudaStream_t stream);
+
 nvjpegStatus_t NVJPEGAPI nvjpegEncodeRetrieveBitstreamDevice(
         nvjpegHandle_t handle,
         nvjpegEncoderState_t encoder_state,
@@ -810,12 +847,6 @@ nvjpegStatus_t nvjpegEncoderParamsCopyQuantizationTables(
     nvjpegJpegStream_t jpeg_stream,
     cudaStream_t stream);
 
-// copies huffman tables from parsed stream. should require same scans structure
-nvjpegStatus_t nvjpegEncoderParamsCopyHuffmanTables(
-    nvjpegEncoderState_t encoder_state,
-    nvjpegEncoderParams_t encode_params,
-    nvjpegJpegStream_t jpeg_stream,
-    cudaStream_t stream);
 
 #if defined(__cplusplus)
   }
