@@ -1035,22 +1035,29 @@ nvfs_direct_io(int op, struct file *filp, char __user *buf,
 
         iov_iter_init(&iter, op, &iov, 1, len);
 
-//TODO: If the config is not present fallback to vfs_read/vfs_write
-#ifdef HAVE_CALL_READ_WRITE_ITER
         if(op == WRITE) {
                 set_write_flag(&nvfsio->common);
                 file_start_write(filp);
 
+#ifdef HAVE_CALL_READ_WRITE_ITER
                 ret = nvfs_io_ret(&nvfsio->common,
 				call_write_iter(filp, &nvfsio->common, &iter));
+#else
+		ret = nvfs_io_ret(&nvfsio->common,
+                                filp->f_op->write_iter(&nvfsio->common, &iter));
+#endif
                 if (S_ISREG(file_inode(filp)->i_mode))
                         __sb_writers_release(file_inode(filp)->i_sb,
 				SB_FREEZE_WRITE);
         } else {
+#ifdef HAVE_CALL_READ_WRITE_ITER
                 ret = nvfs_io_ret(&nvfsio->common,
 				call_read_iter(filp, &nvfsio->common, &iter));
-        }
+#else
+		ret = nvfs_io_ret(&nvfsio->common,
+                                filp->f_op->read_iter(&nvfsio->common, &iter));
 #endif
+        }
 
         nvfs_dbg("nvfs_direct_io : ret = %ld len = %lu\n" , ret, len);
         if (ret == -EIOCBQUEUED) {
